<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:aid="http://ns.adobe.com/AdobeInDesign/4.0/"
xmlns:xlink="http://www.w3.org/1999/xlink"
 xmlns:ali="http://www.niso.org/schemas/ali/1.0/"
exclude-result-prefixes="aid">

<xsl:output method="xml" encoding="utf-8" indent="yes" doctype-public="-//NLM//DTD JATS (Z39.96) Journal Publishing DTD v0.4 20110131//EN" doctype-system="https://www.jstage.jst.go.jp/dtds/1.1/JATS-journalpublishing1.dtd" />

<xsl:template match="Root">
<article xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:ali="http://www.niso.org/schemas/ali/1.0/" xml:lang="ja" dtd-version="1.1" article-type="research-article">


<xsl:call-template name="front" /><xsl:text>&#xA;</xsl:text>
<xsl:call-template name="body" /><xsl:text>&#xA;</xsl:text>
<xsl:call-template name="back" /><xsl:text>&#xA;</xsl:text>
</article>
</xsl:template>

<xsl:template name="front">
<front>
<journal-meta>
<journal-id journal-id-type="j-stage">【ジャーナルID】</journal-id>
<journal-title-group>
<journal-title xml:lang="ja"><xsl:value-of select="変数定義/journal-title" /></journal-title>
<trans-title-group xml:lang="en">
<trans-title>【ジャーナルタイトル英語】</trans-title>
</trans-title-group>
<abbrev-journal-title>【ジャーナルタイトル略称】</abbrev-journal-title>
</journal-title-group>
<issn pub-type="ppub">【ppub】</issn>
<issn pub-type="epub">【epub】</issn>
<issn-l>【issn-l】</issn-l>
</journal-meta>
<article-meta>
<article-id pub-id-type="doi">【doi】</article-id>
<title-group>
<article-title><xsl:value-of select="//タイトル日本語" /></article-title>
<subtitle><xsl:value-of select="//サブタイトル日本語" /></subtitle>
<trans-title-group  xml:lang="en">
<trans-title><xsl:value-of select="//タイトル英語" /></trans-title>
<trans-subtitle><xsl:value-of select="//サブタイトル英語" /></trans-subtitle>
</trans-title-group>
</title-group>

<contrib-group>
<xsl:for-each select="//著者日本語">
<xsl:variable name="key" select="position()" />
<contrib contrib-type="author">
<name-alternatives>
<name name-style="eastern">
<surname><xsl:value-of select="surname" /></surname>
<given-names><xsl:value-of select="given-names" /></given-names>
</name>
<name name-style="western" xml:lang="en">
<xsl:for-each select="//著者英語[$key]">
<surname><xsl:value-of select="surname" /></surname>
<given-names><xsl:value-of select="given-names" /></given-names>
</xsl:for-each>
</name>
</name-alternatives>
<xsl:for-each select="所属番号">
<xref rid="aff{.}" ref-type="aff"><xsl:value-of select="." /></xref>
</xsl:for-each>
</contrib>
</xsl:for-each>
<xsl:for-each select="//所属日本語">
<xsl:variable name="no" select="所属番号" />
<aff-alternatives id="aff{所属番号}">
<aff xml:lang="ja">
<institution><xsl:value-of select="所属名称" /></institution>
</aff>
<xsl:for-each select="//所属英語[所属番号=$no]">
<aff xml:lang="en">
<institution><xsl:value-of select="所属名称" /></institution>
</aff>
</xsl:for-each>
</aff-alternatives>
</xsl:for-each>
</contrib-group>
<pub-date pub-type="ppub">
<day>【日】</day>
<month>【月】</month>
<year>【年】</year>
</pub-date>
<volume><xsl:value-of select="変数定義/volume" /></volume>
<issue><xsl:value-of select="変数定義/issue" /></issue>
<fpage><xsl:value-of select="変数定義/fpage" /></fpage>
<lpage><xsl:value-of select="変数定義/lpage" /></lpage>
<history>
<date date-type="received">
<day>【日】</day>
<month>【月】</month>
<year>【年】</year>
</date>
<date date-type="accepted">
<day>【日】</day>
<month>【月】</month>
<year>【年】</year>
</date>
</history>
<permissions>
<copyright-statement>Copyright &#x00A9; {$PUBDATE}, 【copyright-statement日本語】</copyright-statement>
<copyright-statement xml:lang="en">Copyright &#x00A9; {$PUBDATE}, 【copyright-statement英語】</copyright-statement>
<copyright-year>{$PUBDATE}</copyright-year>
<copyright-holder>【copyright-holder日本語】</copyright-holder>
<copyright-holder xml:lang="en">【copyright-holder英語】</copyright-holder>
<license license-type="open-access">
<license-p>
この記事はクリエイティブ・コモンズ<ext-link xlink:href="https://creativecommons.org/licenses/by/4.0/deed.ja" ext-link-type="uri">[表示 4.0 国際]</ext-link>ライセンスの下に提供されています。
<open-access><p>オープンアクセス規定</p></open-access>
</license-p>
<ali:license_ref>https://creativecommons.org/licenses/by-nd/4.0/deed.ja</ali:license_ref>
</license>
</permissions>
<xsl:if test="//アブストラクト日本語!=''">
<abstract>
<xsl:if test="//アブストラクト日本語/title!=''"><title><xsl:value-of select="//アブストラクト日本語/title" /></title></xsl:if>
<p><xsl:copy-of select="//アブストラクト日本語/node()" /></p>
</abstract>
<trans-abstract xml:lang="en">
<xsl:if test="//アブストラクト英語/title!=''"><title><xsl:value-of select="//アブストラクト英語/title" /></title></xsl:if>
<p><xsl:copy-of select="//アブストラクト英語/node()" /></p>
</trans-abstract>
<kwd-group kwd-group-type="author">
<xsl:for-each select="//キーワード日本語">
<kwd><xsl:copy-of select="node()" /></kwd>
</xsl:for-each>
</kwd-group>
<kwd-group kwd-group-type="author" xml:lang="en">
<xsl:for-each select="//キーワード英語">
<kwd><xsl:copy-of select="node()" /></kwd>
</xsl:for-each>
</kwd-group>
</xsl:if>
</article-meta>
</front>
</xsl:template>

<xsl:template name="body">
<body>
<xsl:apply-templates select="//ストーリー/sec" />
</body>
</xsl:template>

<xsl:template match="sec">
<xsl:copy>
<xsl:copy-of select="title" />
<xsl:apply-templates select="p | table-wrap | list | fig" />
<xsl:if test="sec!=''">
<xsl:apply-templates select="sec" />
</xsl:if>
</xsl:copy>
</xsl:template>

<xsl:template match="table-wrap">
<table-wrap id="{@id}">
<label><xsl:value-of select="caption/label" /></label>
<caption>
<xsl:if test="caption/title != ''"><title><xsl:value-of select="caption/title" /></title></xsl:if>
<xsl:for-each select="caption/p">
<xsl:copy-of select="." />
</xsl:for-each>
</caption>
<xsl:apply-templates select="表" />
<xsl:copy-of select="table-wrap-foot" />
</table-wrap>
</xsl:template>

<xsl:template match="表">
<table>
<xsl:variable name="max" select="@aid:tcols"/>
<thead>
<tr>
<xsl:for-each select="セル[@aid:theader]">
<th align="center" colspan="{@aid:ccols}" rowspan="{@aid:crows}"><p><xsl:copy-of select="th/node()" /></p></th>
</xsl:for-each>
</tr>
</thead>
<tbody>
<xsl:for-each select="セル[not(@aid:theader) and not(@aid:tfooter)]">
<xsl:variable name="sum" select="sum(preceding-sibling::セル/@aid:ccols)"/>
<xsl:if test="$sum mod $max = 0">
<tr>
<xsl:apply-templates select="."/>
<xsl:for-each select="following-sibling::セル[sum(preceding-sibling::セル/@aid:ccols) &lt; $sum+$max]">
<xsl:apply-templates select="."/>
</xsl:for-each>
</tr>
</xsl:if>
</xsl:for-each>
</tbody>
</table>
<xsl:apply-templates select="セル[@aid:tfooter]" />
</xsl:template>
    
<xsl:template match="セル">
<xsl:choose>
<xsl:when test="th">
<th align="left" colspan="{@aid:ccols}" rowspan="{@aid:crows}"><p><xsl:copy-of select="th/node()" /></p></th>
</xsl:when>
<xsl:when test="td">
<td align="left" colspan="{@aid:ccols}" rowspan="{@aid:crows}"><p><xsl:copy-of select="td/node()"/></p></td>
</xsl:when>
<xsl:otherwise>
<td align="left" colspan="{@aid:ccols}" rowspan="{@aid:crows}"><p><xsl:copy-of select="td/node()"/></p></td>   
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="セル[@aid:tfooter]">
<table-wrap-foot id="table-wrap-foot_id_{position()}">
<fn id="{fn/@id}">
<p><xsl:copy-of select="fn/node()" /></p>
</fn>
</table-wrap-foot>
</xsl:template>


<xsl:template match="list">
<list list-type="{@list-type}">
<xsl:for-each select="リスト">
<list-item>
<label><xsl:value-of select="@label" /></label>
<p><xsl:copy-of select="node()" /></p>
</list-item>
</xsl:for-each>
</list>
</xsl:template>

<xsl:template match="fig">
<fig id="{@id}">
<label><xsl:value-of select="caption/label" /></label>
<caption>
<xsl:if test="caption/title != ''"><title><xsl:value-of select="caption/title" /></title></xsl:if>
<xsl:if test="caption/p != ''">
<xsl:for-each select="caption/p">
<xsl:copy-of select="." />
</xsl:for-each>
</xsl:if>
</caption>
<graphic xlink:href="{graphic/@href_fmt}"/>
</fig>
</xsl:template>

<xsl:template match="ext-link">
<ext-link>
<xsl:attribute name="xlink:href"><xsl:value-of select="@url" /></xsl:attribute>
<xsl:value-of select="." />
</ext-link>
</xsl:template>

<xsl:template match="inline-graphic">
<inline-graphic>
<xsl:attribute name="xlink:href"><xsl:value-of select="@href_fmt" /></xsl:attribute>
<xsl:value-of select="." />
</inline-graphic>
</xsl:template>

<xsl:template match="p">
<xsl:if test="node()!=''">
<xsl:copy>
<xsl:apply-templates select="@* | node()" />
</xsl:copy>
</xsl:if>
</xsl:template>

<xsl:template match="@* | node()">
<xsl:copy-of select="." />
</xsl:template>

<xsl:template name="back">
<back>
<ref-list>
<xsl:for-each select="//引用文献">
<xsl:choose>
<xsl:when test="文献日本語 != ''">
<ref id="B{position()}" xml:lang="ja">
<label><xsl:value-of select="label" /></label>
<mixed-citation publication-type="{@publication-type}">
<xsl:copy-of select="文献日本語/node()" />
</mixed-citation>
</ref>
</xsl:when>
<xsl:when test="文献英語 != ''">
<ref id="B{position()}" xml:lang="en">
<label><xsl:value-of select="label" /></label>
<mixed-citation publication-type="{@publication-type}">
<xsl:copy-of select="文献英語/node()" />
</mixed-citation>
</ref>
</xsl:when>
<xsl:otherwise>
<ref id="B{position()}" xml:lang="【lang】">
<label><xsl:value-of select="label" /></label>
<mixed-citation publication-type="{@publication-type}">
<xsl:copy-of select="文献/node()" />
</mixed-citation>
</ref>
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>
</ref-list>

<xsl:for-each select="//謝辞">
<xsl:choose>
<xsl:when test="謝辞日本語">
<ack xml:lang="ja">
<xsl:if test="label != ''"><label><xsl:value-of select="label" /></label></xsl:if>
<title><xsl:value-of select="title" /></title>
<xsl:for-each select="謝辞日本語">
<p><xsl:copy-of select="node()" /></p>
</xsl:for-each>
</ack>
</xsl:when>
<xsl:when test="謝辞英語">
<ack xml:lang="en">
<xsl:if test="label != ''"><label><xsl:value-of select="label" /></label></xsl:if>
<title><xsl:value-of select="title" /></title>
<xsl:for-each select="謝辞英語">
<p><xsl:copy-of select="node()" /></p>
</xsl:for-each>
</ack>
</xsl:when>
</xsl:choose>
</xsl:for-each>

    
<xsl:for-each select="//notes">
<notes id="{@id}">
<xsl:if test="label != ''"><label><xsl:value-of select="label" /></label></xsl:if>
<title><xsl:value-of select="title" /></title>
<xsl:for-each select="注釈">
<p><xsl:copy-of select="node()" /></p>
</xsl:for-each>
</notes>
</xsl:for-each>
</back>
</xsl:template>

</xsl:stylesheet>
